Ocyan plugin Ocyan Invoice Payment Plugin
=======================================

About Ocyan Invoice Payment Plugin
--------------------------------
Ocyan Invoice Payment Plugin

Installation
------------
Add `ocyan.plugin.payment_invoice` to your projects dependencies.

Options
-------

There are four different invoice payments possible without the need to
override any code. You can activate them in ocyan.json if you need more than
the default invoice payment. You can just override the corresponding template
to implement the different payment. The name of the payment can be changed
by means of the locale.
